pub struct FirefoxLabsEnrollResult {
pub status: FirefoxLabsEnrollStatus,
pub enrollment_change_events: Vec<EnrollmentChangeEvent>,
}Fields
status: FirefoxLabsEnrollStatusenrollment_change_events: Vec<EnrollmentChangeEvent>Trait Implementations
Sourceimpl<UT> ConvertError<UT> for FirefoxLabsEnrollResult
impl<UT> ConvertError<UT> for FirefoxLabsEnrollResult
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for FirefoxLabsEnrollResult
impl<UT> FfiConverter<UT> for FirefoxLabsEnrollResult
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for FirefoxLabsEnrollResult
impl<UT> Lift<UT> for FirefoxLabsEnrollResult
Sourceimpl<UT> LiftRef<UT> for FirefoxLabsEnrollResult
impl<UT> LiftRef<UT> for FirefoxLabsEnrollResult
Sourceimpl<UT> LiftReturn<UT> for FirefoxLabsEnrollResult
impl<UT> LiftReturn<UT> for FirefoxLabsEnrollResult
Sourcetype ReturnType = <FirefoxLabsEnrollResult as Lift<UT>>::FfiType
type ReturnType = <FirefoxLabsEnrollResult as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for FirefoxLabsEnrollResult
impl<UT> Lower<UT> for FirefoxLabsEnrollResult
Sourceimpl<UT> LowerError<UT> for FirefoxLabsEnrollResult
impl<UT> LowerError<UT> for FirefoxLabsEnrollResult
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for FirefoxLabsEnrollResult
impl<UT> LowerReturn<UT> for FirefoxLabsEnrollResult
Sourcetype ReturnType = <FirefoxLabsEnrollResult as Lower<UT>>::FfiType
type ReturnType = <FirefoxLabsEnrollResult as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl<UT> TypeId<UT> for FirefoxLabsEnrollResult
impl<UT> TypeId<UT> for FirefoxLabsEnrollResult
const TYPE_ID_META: MetadataBuffer